@@ -72,6 +72,9 @@ do_ChordDiagramPlot <- function(sample = NULL,
                                 annotationTrack = c("grid", "axis"),
                                 padding_labels = 4,
                                 ...){
+  # Add lengthy error messages.
+  withr::local_options(.new = list("warning.length" = 8170))
+
   `%>%` <- magrittr::`%>%`
   check_suggests(function_name = "do_ChordDiagramPlot")
   # Check logical parameters.
@@ -117,38 +120,106 @@ do_ChordDiagramPlot <- function(sample = NULL,
     data <- extra_params[["df"]]
 
     assertthat::assert_that("data.frame" %in% class(data),
-                            msg = "Please provide a data.frame or tibble to df.")
+                            msg = paste0(add_cross(), crayon_body("Please provide a "),
+                                         crayon_key("data.frame"),
+                                         crayon_body(" or a "),
+                                         crayon_key("tibble"),
+                                         crayon_body(" to the parameter "),
+                                         crayon_key("df"),
+                                         crayon_body(".")))
 
     assertthat::assert_that(ncol(data) == 3,
-                            msg = "If you pass from_df and df to this function, make sure that the df has 3 columns.")
+                            msg = paste0(add_cross(), crayon_body("If you make use of "),
+                                         crayon_key("from_df"),
+                                         crayon_body(" parameter, make sure that the dataframe provided to "),
+                                         crayon_key("df"),
+                                         crayon_body(" has at least "),
+                                         crayon_key("three"),
+                                         crayon_body(" columns.")))
 
     assertthat::assert_that(sum(colnames(data) %in% c("from", "to", "value")) == 3,
-                            msg = "Please name the columns in the df as: from, to and value.")
+                            msg = paste0(add_cross(), crayon_body("If you make use of "),
+                                         crayon_key("from_df"),
+                                         crayon_body(" parameter, make sure that the dataframe provided to "),
+                                         crayon_key("df"),
+                                         crayon_body(" has at least "),
+                                         crayon_key("three"),
+                                         crayon_body(" columns named: "),
+                                         crayon_key("from"),
+                                         crayon_body(", "),
+                                         crayon_key("to"),
+                                         crayon_body(" and "),
+                                         crayon_key("value"),
+                                         crayon_body(".")))
 
     assertthat::assert_that(class(data[["from"]]) %in% c("factor", "character"),
-                            msg = "Please make sure that the column from is either a factor or a character column.")
+                            msg = paste0(add_cross(), crayon_body("Make sure that the column named "),
+                                         crayon_key("from"),
+                                         crayon_body(" in the dataframe provided to "),
+                                         crayon_key("df"),
+                                         crayon_body(" is a "),
+                                         crayon_key("character"),
+                                         crayon_body(" or "),
+                                         crayon_key("factor"),
+                                         crayon_body(" column.")))
 
     assertthat::assert_that(class(data[["to"]]) %in% c("factor", "character"),
-                            msg = "Please make sure that the column to is either a factor or a character column.")
+                            msg = paste0(add_cross(), crayon_body("Make sure that the column named "),
+                                         crayon_key("to"),
+                                         crayon_body(" in the dataframe provided to "),
+                                         crayon_key("df"),
+                                         crayon_body(" is a "),
+                                         crayon_key("character"),
+                                         crayon_body(" or "),
+                                         crayon_key("factor"),
+                                         crayon_body(" column.")))
 
-    assertthat::assert_that(class(data[["value"]]) %in% c("integer"),
-                            msg = "Please make sure that the column value is either an integer column.")
+    assertthat::assert_that("integer" %in% class(data[["value"]]),
+                            msg = paste0(add_cross(), crayon_body("Make sure that the column named "),
+                                         crayon_key("from"),
+                                         crayon_body(" in the dataframe provided to "),
+                                         crayon_key("df"),
+                                         crayon_body(" is a "),
+                                         crayon_key("numeric"),
+                                         crayon_body(" column.")))
 
   }  else {
     assertthat::assert_that(!is.null(sample),
-                            msg = "Please provide a Seurat object.")
+                            msg = paste0(add_cross(), crayon_body("Please provide a "),
+                                         crayon_key("Seurat object"),
+                                         crayon_body(" to the parameter "),
+                                         crayon_key("sample"),
+                                         crayon_body(".")))
 
     # Check if the sample provided is a Seurat object.
     check_Seurat(sample = sample)
 
     assertthat::assert_that(!is.null(from) | !is.null(to),
-                            msg = "Please provide a value to: from or to parameters.")
+                            msg = paste0(add_cross(), crayon_body("Please provide a value to "),
+                                         crayon_key("from"),
+                                         crayon_body(" or "),
+                                         crayon_key("to"),
+                                         crayon_body(" parameters.")))
 
     assertthat::assert_that(from %in% colnames(sample@meta.data) | to %in% colnames(sample@meta.data),
-                            msg = "From or to parameters have to be in the object metadata.")
+                            msg = paste0(add_cross(), crayon_body("Parameters "),
+                                         crayon_key("from"),
+                                         crayon_body(" and "),
+                                         crayon_key("to"),
+                                         crayon_body(" need to be present in the object "),
+                                         crayon_key("metadata"),
+                                         crayon_body(".")))
 
     assertthat::assert_that(class(sample@meta.data[, from]) %in% c("factor", "character") | class(sample@meta.data[, to]) %in% c("factor", "character"),
-                            msg = "Parameters from or to have to be either a factor or a character column in the object metadata.")
+                            msg = paste0(add_cross(), crayon_body("Parameters "),
+                                         crayon_key("from"),
+                                         crayon_body(" and "),
+                                         crayon_key("to"),
+                                         crayon_body(" need to be either a "),
+                                         crayon_key("factor"),
+                                         crayon_body(" or "),
+                                         crayon_key("character"),
+                                         crayon_body(" columns.")))
 
     data <- sample@meta.data %>%
             tibble::as_tibble() %>%
@@ -219,7 +290,7 @@ do_ChordDiagramPlot <- function(sample = NULL,
   names(colors.to) <- stringr::str_pad(names(colors.to), width = max_char, side = "both")
   colors.use <- c(colors.from, colors.to)
   if (is.null(link.sort)){link.sort <- "default"}
-  if (isFALSE(z_index)){link.zindex <- NULL} else {link.zindex <- rank(data[["value"]])}
+  if (base::isFALSE(z_index)){link.zindex <- NULL} else {link.zindex <- rank(data[["value"]])}
 
   if (alignment == "vertical"){
     circlize::circos.par(start.degree = 0)
@@ -232,7 +303,7 @@ do_ChordDiagramPlot <- function(sample = NULL,
   }
 
   if (!(is.null(highlight_group))){
-    alpha.colors <- c()
+    alpha.colors <- NULL
     highlight_group <- stringr::str_pad(highlight_group, width = max_char, side = "both")
     for (color in names(colors.use)){
       name <- color
