@@ -12,7 +12,7 @@
     p <- SCpubr::do_CorrelationPlot(sample = sample)
     p
 
-  } else if (isFALSE(value)){
+  } else if (base::isFALSE(value)){
     message("This function can not be used without its suggested packages.")
     message("Check out which ones are needed using `SCpubr::state_dependencies()`.")
   }
