@@ -13,7 +13,7 @@
     # Default plot.
     p <- SCpubr::do_TermEnrichmentPlot(enriched_terms = enriched_terms)
     p
-  } else if (isFALSE(value)){
+  } else if (base::isFALSE(value)){
     message("This function can not be used without its suggested packages.")
     message("Check out which ones are needed using `SCpubr::state_dependencies()`.")
   }
