@@ -1,4 +1,4 @@
-if(isFALSE(dep_check[["do_ViolinPlot"]])){
+if(base::isFALSE(dep_check[["do_ViolinPlot"]])){
   testthat::test_that("do_ViolinPlot: CRAN essentials", {
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
@@ -125,7 +125,7 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
                                features = "EPC1",
-                               rotate_x_axis_labels = 45)
+                               axis.text.x.angle = 45)
     testthat::expect_type(p, "list")
   })
 
@@ -134,7 +134,7 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               features = c("EPC1"),
+                               features = "EPC1",
                                plot.grid = TRUE)
     testthat::expect_type(p, "list")
   })
@@ -147,8 +147,8 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               features = c("EPC1"),
-                               rotate_x_axis_labels = 45,
+                               features = "EPC1",
+                               axis.text.x.angle = 45,
                                y_cut = 2)
     testthat::expect_type(p, "list")
   })
@@ -159,8 +159,8 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               features = c("EPC1"),
-                               rotate_x_axis_labels = 45,
+                               features = "EPC1",
+                               axis.text.x.angle = 45,
                                y_cut = 2,
                                line_width = 3)
     testthat::expect_type(p, "list")
@@ -171,8 +171,8 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               features = c("EPC1"),
-                               rotate_x_axis_labels = 45,
+                               features = "EPC1",
+                               axis.text.x.angle = 45,
                                y_cut = 2,
                                boxplot_width = 0.1)
     testthat::expect_type(p, "list")
@@ -183,8 +183,8 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               features = c("EPC1"),
-                               rotate_x_axis_labels = 45,
+                               features = "EPC1",
+                               axis.text.x.angle = 45,
                                y_cut = 2,
                                boxplot_width = 0.1,
                                colors.use = c("0" = "#001219",
@@ -206,7 +206,7 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
     testthat::expect_error(SCpubr::do_ViolinPlot(sample = sample,
-                                                 features = c("EPC1"),
+                                                 features = "EPC1",
                                                  split.by = "orig.ident"))
   })
 
@@ -278,14 +278,14 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               c("EPC1"),
+                               "EPC1",
                                group.by = "orig.ident",
                                colors.use = c("Cell" = "red"))
     testthat::expect_type(p, "list")
 
     sample$orig.ident <- factor(sample$orig.ident)
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               c("EPC1"),
+                               "EPC1",
                                group.by = "orig.ident",
                                colors.use = c("Cell" = "red"))
     testthat::expect_type(p, "list")
@@ -296,7 +296,7 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
     testthat::expect_error(SCpubr::do_ViolinPlot(sample = sample,
-                                                 features = c("EPC1"),
+                                                 features = "EPC1",
                                                  font.type = "wrong"))
   })
 
@@ -305,7 +305,7 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
     testthat::expect_error(SCpubr::do_ViolinPlot(sample = sample,
-                                                 features = c("EPC1"),
+                                                 features = "EPC1",
                                                  split.by = "annotation"))
   })
 }
